bayesx.
Before STAR models can be estimated, the command-line version of bayesx and bayesx.control for more details on model fitting
and controlling.
The package also provides functionality for high level graphics of estimated effects, see function
plot.bayesx, plot2d, plot3d, plotblock,
plotmap, plotsamples and colorlegend.
More standard extractor functions and methods for the fitted model objects may be applied, e.g.,
see function summary.bayesx, fitted.bayesx,
residuals.bayesx, samples, plot.bayesx, as well as
AIC, BIC etc., please see the examples of the help
sites. Predictions for new data based on refitting with weights can be obtained by function
predict.bayesx.
In addition, it is possible to run arbitrary run.bayesx. read.bayesx.output.## to see the package demos
demo(package = "R2BayesX")Run the code above in your browser using DataLab