sx may have
additional optional control arguments. Therefore function
bayesx.term.options displays the possible additional controlling parameters for a
particular model term.bayesx.term.options(bs = "ps", method = "MCMC")"MCMC",
"REML" and "STEP"."rw1","rw2": Zero degree P-splines: Defines a zero degree P-spline with first or
second order difference penalty. A zero degree P-spline typically
estimates for every distinct covariate value in the dataset a separate
parameter. Usually there is no reason to prefer zero degree P-splines
over higher order P-splines. An exception are ordinal covariates or
continuous covariates with only a small number of different values.
For ordinal covariates higher order P-splines are not meaningful while
zero degree P-splines might be an alternative to modeling nonlinear
relationships via a dummy approach with completely unrestricted
regression parameters."season": Seasonal effect of a time scale."ps","psplinerw1","psplinerw2": P-spline with first or second order
difference penalty."te","pspline2dimrw1": Defines a two-dimensional P-spline based on the tensor
product of one-dimensional P-splines with a two-dimensional first order random walk
penalty for the parameters of the spline."kr","kriging": Kriging with stationary Gaussian random fields."gk","geokriging": Geokriging with stationary Gaussian random fields: Estimation
is based on the centroids of a map object provided in
boundary format (see functionread.bndandshp2bnd) as an additional
argument namedmapwithin functionsx, or supplied within argumentxtwhen using functions, e.g.,xt = list(map = MapBnd)."gs","geospline": Geosplines based on two-dimensional P-splines with a
two-dimensional first order random walk penalty for the parameters of the spline.
Estimation is based on the coordinates of the centroids of the regions
of a map object provided in boundary format (see functionread.bndandshp2bnd) as an additional argument namedmap(see above)."mrf","spatial": Markov random fields: Defines a Markov random field prior for a
spatial covariate, where geographical information is provided by a map object in
boundary or graph file format (see functionread.bnd,read.graandshp2bnd), as an additional argument namedmap(see above)."bl","baseline": Nonlinear baseline effect in hazard regression or multi-state
models: Defines a P-spline with second order random walk penalty for the parameters of
the spline for the log-baseline effect$log(\lambda(time))$."factor": Specialmethod = "STEP", since the factor term is then treated as a full term,
which is either included or removed from the model."ridge","lasso","nigmix": Shrinkage of fixed effects: defines a
shrinkage-prior for the corresponding parameters$\gamma_j$,$j = 1, \ldots, q$,$q \geq 1$of the
linear effects$x_1, \ldots, x_q$. There are three
priors possible: ridge-, lasso- and Normal Mixture
of inverse Gamma prior."re": Gaussian i.i.d. Random effects of a unit or cluster identification covariate.## show arguments for P-splines
bayesx.term.options(bs = "ps")
bayesx.term.options(bs = "ps", method = "REML")
## Markov random fields
bayesx.term.options(bs = "mrf")Run the code above in your browser using DataLab